@@ -1,14 +1,14 @@
 package Search::Elasticsearch;
 
-use Moo 1.003 ();
+use Moo 2.001000 ();
 
 use Search::Elasticsearch::Util qw(parse_params load_plugin);
 use namespace::clean;
 
-our $VERSION = '5.00';
+our $VERSION = '6.80_01';
 
 my %Default_Plugins = (
-    client      => [ 'Search::Elasticsearch::Client',       '5_0::Direct' ],
+    client      => [ 'Search::Elasticsearch::Client',       '6_0::Direct' ],
     cxn_factory => [ 'Search::Elasticsearch::Cxn::Factory', '' ],
     cxn_pool    => [ 'Search::Elasticsearch::CxnPool',      'Static' ],
     logger      => [ 'Search::Elasticsearch::Logger',       'LogAny' ],
@@ -62,7 +62,7 @@ Search::Elasticsearch - The official client for Elasticsearch
 
 =head1 VERSION
 
-version 5.00
+version 6.80_01
 
 =head1 SYNOPSIS
 
@@ -134,7 +134,7 @@ version 5.00
 =head1 DESCRIPTION
 
 L<Search::Elasticsearch> is the official Perl client for Elasticsearch,
-supported by L<elasticsearch.com|http://www.elasticsearch.com>.  Elasticsearch
+supported by L<elastic.co|http://elastic.co>.  Elasticsearch
 itself is a flexible and powerful open source, distributed real-time
 search and analytics engine for the cloud.  You can read more about it
 on L<elastic.co|http://www.elastic.co>.
@@ -212,8 +212,8 @@ Good defaults
 =item *
 
 Helper utilities for more complex operations, such as
-L<bulk indexing|Search::Elasticsearch::Client::5_0::Bulk>, and
-L<scrolled searches|Search::Elasticsearch::Client::5_0::Scroll>
+L<bulk indexing|Search::Elasticsearch::Client::6_0::Bulk>, and
+L<scrolled searches|Search::Elasticsearch::Client::6_0::Scroll>
 
 =item *
 
@@ -239,7 +239,7 @@ preferably the Java v8 from Sun.
 
 =head1 CREATING A NEW INSTANCE
 
-The L</new()> method returns a new L<client|Search::Elasticsearch::Client::5_0::Direct>
+The L</new()> method returns a new L<client|Search::Elasticsearch::Client::6_0::Direct>
 which can be used to run requests against the Elasticsearch cluster.
 
     use Search::Elasticsearch;
@@ -359,7 +359,7 @@ Other arguments are explained in the respective L<module docs|/MODULES>.
 =head1 RUNNING REQUESTS
 
 When you create a new instance of Search::Elasticsearch, it returns a
-L<client|Search::Elasticsearch::Client::5_0::Direct> object, which can be used for
+L<client|Search::Elasticsearch::Client::6_0::Direct> object, which can be used for
 running requests.
 
     use Search::Elasticsearch;
@@ -380,7 +380,7 @@ running requests.
         }
     );
 
-See L<Search::Elasticsearch::Client::5_0::Direct> for more details about the requests that
+See L<Search::Elasticsearch::Client::6_0::Direct> for more details about the requests that
 can be run.
 
 =head1 MODULES
@@ -412,11 +412,11 @@ methods that can be called to execute requests, such as
 C<search()>, C<index()> or C<delete()>. The client parses the user's
 requests and passes them to the L</transport> class to be executed.
 
-The default version of the client is C<5_0::Direct>, which can
+The default version of the client is C<6_0::Direct>, which can
 be explicitly specified as follows:
 
     $e = Search::Elasticsearch->new(
-        client => '5_0::Direct'
+        client => '6_0::Direct'
     );
 
 =head2 C<transport>
@@ -563,11 +563,11 @@ environment variable:
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
