@@ -1,7 +1,8 @@
-package Search::Elasticsearch::Client::5_0::Direct::Cluster;
-$Search::Elasticsearch::Client::5_0::Direct::Cluster::VERSION = '5.00';
-use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::API';
+package Search::Elasticsearch::Client::6_0::Direct::Cluster;
+$Search::Elasticsearch::Client::6_0::Direct::Cluster::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Client::6_0::Direct::Cluster::VERSION = '6.8001';use Moo;
+with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('cluster');
 
@@ -13,11 +14,11 @@ __PACKAGE__->_install_api('cluster');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Direct::Cluster - A client for running cluster-level requests
+Search::Elasticsearch::Client::6_0::Direct::Cluster - A client for running cluster-level requests
 
 =head1 VERSION
 
-version 5.00
+version 6.80_01
 
 =head1 DESCRIPTION
 
@@ -40,12 +41,15 @@ health, returning C<red>, C<yellow> or C<green> to indicate the state
 of the cluster, indices or shards.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<level>,
     C<local>,
     C<master_timeout>,
     C<timeout>,
     C<wait_for_active_shards>,
     C<wait_for_events>,
+    C<wait_for_no_initializing_shards>,
     C<wait_for_no_relocating_shards>,
     C<wait_for_nodes>,
     C<wait_for_status>
@@ -62,6 +66,7 @@ for more information.
 Returns high-level cluster stats, optionally limited to the listed nodes.
 
 Query string parameters:
+    C<error_trace>,
     C<flat_settings>,
     C<human>,
     C<timeout>
@@ -77,7 +82,9 @@ The C<get_settings()> method is used to retrieve cluster-wide settings that
 have been set with the L</put_settings()> method.
 
 Query string parameters:
+    C<error_trace>,
     C<flat_settings>,
+    C<human>,
     C<include_defaults>,
     C<master_timeout>,
     C<timeout>
@@ -97,12 +104,14 @@ For instance:
 
     $response = $e->cluster->put_settings(
         body => {
-            transient => { "discovery.zen.minimum_master_nodes" => 5 }
+            transient => { "discovery.zen.minimum_master_nodes" => 6 }
         }
     );
 
 Query string parameters:
-    C<flat_settings>
+    C<error_trace>,
+    C<flat_settings>,
+    C<human>
 
 See the L<cluster settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-update-settings.html>
  for more information.
@@ -129,11 +138,15 @@ parameter.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<flat_settings>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>,
-    C<master_timeout>
+    C<master_timeout>,
+    C<wait_for_metadata_version>,
+    C<wait_for_timeout>
 
 See the L<cluster state docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-state.html>
 for more information.
@@ -147,6 +160,8 @@ for more information.
 Returns information about why a shard is allocated or unallocated or why.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<include_disk_info>,
     C<include_yes_decisions>
 
@@ -160,6 +175,8 @@ for more information.
 Returns a list of cluster-level tasks still pending on the master node.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<local>,
     C<master_timeout>
 
@@ -196,7 +213,9 @@ which changes should be made. For instance:
 
 Query string parameters:
     C<dry_run>,
+    C<error_trace>,
     C<explain>,
+    C<human>,
     C<master_timeout>,
     C<metric>,
     C<retry_failed>,
@@ -205,13 +224,26 @@ Query string parameters:
 See the L<reroute docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-reroute.html>
 for more information.
 
+=head2 C<remote_info()>
+
+    $response = $e->cluster->remote_info();
+
+The C<remote_info()> API retrieves all of the configured remote cluster information.
+
+Query string parameters:
+    C<error_trace>,
+    C<human>
+
+See the L<remote_info docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-remote-info.html>
+for more information.
+
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
