@@ -1,13 +1,14 @@
-package Search::Elasticsearch::Client::5_0::Scroll;
-$Search::Elasticsearch::Client::5_0::Scroll::VERSION = '5.00';
-use Moo;
+package Search::Elasticsearch::Client::6_0::Scroll;
+$Search::Elasticsearch::Client::6_0::Scroll::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Client::6_0::Scroll::VERSION = '6.8001';use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use namespace::clean;
 
 has '_buffer' => ( is => 'ro' );
 
 with 'Search::Elasticsearch::Role::Is_Sync',
-    'Search::Elasticsearch::Client::5_0::Role::Scroll';
+    'Search::Elasticsearch::Client::6_0::Role::Scroll';
 
 #===================================
 sub BUILDARGS {
@@ -24,6 +25,9 @@ sub BUILDARGS {
     my $results      = $es->search($params);
 
     my $total = $results->{hits}{total};
+    if (ref $total) {
+        $total = $total->{value}
+    }
 
     return {
         es           => $es,
@@ -109,7 +113,7 @@ sub finish {
     my %args
         = $self->scroll_in_qs
         ? ( scroll_id => $scroll_id )
-        : ( body => $scroll_id );
+        : ( body => { scroll_id => $scroll_id } );
     eval { $self->es->clear_scroll(%args) };
     return 1;
 }
@@ -122,11 +126,11 @@ sub finish {
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Scroll - A helper module for scrolled searches
+Search::Elasticsearch::Client::6_0::Scroll - A helper module for scrolled searches
 
 =head1 VERSION
 
-version 5.00
+version 6.80_01
 
 =head1 SYNOPSIS
 
@@ -156,17 +160,17 @@ until there are no more matching results, much like a cursor in an SQL
 database.
 
 Unlike paginating through results (with the C<from> parameter in
-L<search()|Search::Elasticsearch::Client::5_0::Direct/search()>),
+L<search()|Search::Elasticsearch::Client::6_0::Direct/search()>),
 scrolled searches take a snapshot of the current state of the index. Even
 if you keep adding new documents to the index or updating existing documents,
 a scrolled search will only see the index as it was when the search began.
 
 This module is a helper utility that wraps the functionality of the
-L<search()|Search::Elasticsearch::Client::5_0::Direct/search()> and
-L<scroll()|Search::Elasticsearch::Client::5_0::Direct/scroll()> methods to make
+L<search()|Search::Elasticsearch::Client::6_0::Direct/search()> and
+L<scroll()|Search::Elasticsearch::Client::6_0::Direct/scroll()> methods to make
 them easier to use.
 
-This class does L<Search::Elasticsearch::Client::5_0::Role::Scroll> and
+This class does L<Search::Elasticsearch::Client::6_0::Role::Scroll> and
 L<Search::Elasticsearch::Role::Is_Sync>.
 
 =head1 USE CASES
@@ -231,7 +235,7 @@ C<client_id>:
 
 Very often the I<something> that you will want to do with these results
 involves bulk-indexing them into a new index. The easiest way to
-do this is to use the built-in L<Search::Elasticsearch::Client::5_0::Direct/reindex()>
+do this is to use the built-in L<Search::Elasticsearch::Client::6_0::Direct/reindex()>
 functionality provided by Elasticsearch.
 
 =head1 METHODS
@@ -247,13 +251,13 @@ functionality provided by Elasticsearch.
         %search_params
     );
 
-The L<Search::Elasticsearch::Client::5_0::Direct/scroll_helper()> method loads
-L<Search::Elasticsearch::Client::5_0::Scroll> class and calls L</new()>,
+The L<Search::Elasticsearch::Client::6_0::Direct/scroll_helper()> method loads
+L<Search::Elasticsearch::Client::6_0::Scroll> class and calls L</new()>,
 passing in any arguments.
 
 You can specify a C<scroll> duration (which defaults to C<"1m">) and
 C<scroll_in_qs> (which defaults to C<false>). Any other parameters are
-passed directly to L<Search::Elasticsearch::Client::5_0::Direct/search()>.
+passed directly to L<Search::Elasticsearch::Client::6_0::Direct/search()>.
 
 The C<scroll> duration tells Elasticearch how long it should keep the scroll
 alive.  B<Note>: this duration doesn't need to be long enough to process
@@ -262,7 +266,7 @@ The expiry gets renewed for another C<scroll> period every time new
 a new batch of results is retrieved from the cluster.
 
 By default, the C<scroll_id> is passed as the C<body> to the
-L<scroll|Search::Elasticsearch::Client::5_0::Direct/scroll()> request.
+L<scroll|Search::Elasticsearch::Client::6_0::Direct/scroll()> request.
 To send it in the query string instead, set C<scroll_in_qs> to a true value,
 but be aware: when querying very many indices, the scroll ID can become
 too long for intervening proxies.
@@ -308,7 +312,7 @@ the buffer.
 
 The C<finish()> method clears out the buffer, sets L</is_finished()> to C<true>
 and tries to clear the C<scroll_id> on Elasticsearch.  This API is only
-supported since v0.90.5, but the call to C<clear_scroll> is wrapped in an
+supported since v0.90.6, but the call to C<clear_scroll> is wrapped in an
 C<eval> so the C<finish()> method can be safely called with any version
 of Elasticsearch.
 
@@ -359,21 +363,21 @@ How long the original search plus all subsequent batches took, in milliseconds.
 
 =over
 
-=item * L<Search::Elasticsearch::Client::5_0::Direct/search()>
+=item * L<Search::Elasticsearch::Client::6_0::Direct/search()>
 
-=item * L<Search::Elasticsearch::Client::5_0::Direct/scroll()>
+=item * L<Search::Elasticsearch::Client::6_0::Direct/scroll()>
 
-=item * L<Search::Elasticsearch::Client::5_0::Direct/reindex()>
+=item * L<Search::Elasticsearch::Client::6_0::Direct/reindex()>
 
 =back
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
