@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Cxn::HTTPTiny;
-$Search::Elasticsearch::Cxn::HTTPTiny::VERSION = '6.00';
-use Moo;
+$Search::Elasticsearch::Cxn::HTTPTiny::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Cxn::HTTPTiny::VERSION = '6.8001';use Moo;
 with 'Search::Elasticsearch::Role::Cxn', 'Search::Elasticsearch::Role::Is_Sync';
 
 use HTTP::Tiny 0.043 ();
@@ -85,7 +86,7 @@ Search::Elasticsearch::Cxn::HTTPTiny - A Cxn implementation which uses HTTP::Tin
 
 =head1 VERSION
 
-version 6.00
+version 6.80_01
 
 =head1 DESCRIPTION
 
@@ -259,11 +260,11 @@ From L<Search::Elasticsearch::Role::Cxn>
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
