@@ -1,9 +1,10 @@
 package Search::Elasticsearch::Cxn::Hijk;
-$Search::Elasticsearch::Cxn::Hijk::VERSION = '5.00';
-use Moo;
+$Search::Elasticsearch::Cxn::Hijk::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Cxn::Hijk::VERSION = '6.8001';use Moo;
 with 'Search::Elasticsearch::Role::Cxn', 'Search::Elasticsearch::Role::Is_Sync';
 
-use Hijk;
+use Hijk 0.27;
 use Try::Tiny;
 use namespace::clean;
 
@@ -46,10 +47,13 @@ sub perform_request {
     if ( defined $params->{data} ) {
         $args{body} = $params->{data};
         $args{head} = [ 'Content-Type', $params->{mime_type} ];
-        push @{ $args{headers} }, ( 'Content-Encoding', $params->{encoding} )
+        push @{ $args{head} }, ( 'Content-Encoding', $params->{encoding} )
             if $params->{encoding};
     }
 
+    push @{ $args{head} }, %{$self->default_headers}
+        if %{$self->default_headers};
+
     my $response;
     try {
         local $SIG{PIPE} = sub { die $! };
@@ -119,7 +123,7 @@ Search::Elasticsearch::Cxn::Hijk - A Cxn implementation which uses Hijk
 
 =head1 VERSION
 
-version 5.00
+version 6.80_01
 
 =head1 DESCRIPTION
 
@@ -257,11 +261,11 @@ From L<Search::Elasticsearch::Role::Cxn>
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
