@@ -1,6 +1,7 @@
 package Search::Elasticsearch::CxnPool::Static;
-$Search::Elasticsearch::CxnPool::Static::VERSION = '5.00';
-use Moo;
+$Search::Elasticsearch::CxnPool::Static::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::CxnPool::Static::VERSION = '6.8001';use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Static',
     'Search::Elasticsearch::Role::Is_Sync';
 use Search::Elasticsearch::Util qw(throw);
@@ -50,7 +51,7 @@ Search::Elasticsearch::CxnPool::Static - A CxnPool for connecting to a remote cl
 
 =head1 VERSION
 
-version 5.00
+version 6.80_01
 
 =head1 SYNOPSIS
 
@@ -177,11 +178,11 @@ From L<Search::Elasticsearch::Role::CxnPool>
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
