@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Logger::LogAny;
-$Search::Elasticsearch::Logger::LogAny::VERSION = '6.00';
-use Moo;
+$Search::Elasticsearch::Logger::LogAny::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Logger::LogAny::VERSION = '6.8001';use Moo;
 with 'Search::Elasticsearch::Role::Logger';
 use Search::Elasticsearch::Util qw(parse_params to_list);
 use namespace::clean;
@@ -57,7 +58,7 @@ Search::Elasticsearch::Logger::LogAny - A Log::Any-based Logger implementation
 
 =head1 VERSION
 
-version 6.00
+version 6.80_01
 
 =head1 DESCRIPTION
 
@@ -134,11 +135,11 @@ See L<Log::Any::Adapter> for more.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
