@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Role::API;
-$Search::Elasticsearch::Role::API::VERSION = '5.00';
-use Moo::Role;
+$Search::Elasticsearch::Role::API::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Role::API::VERSION = '6.8001';use Moo::Role;
 requires 'api_version';
 requires 'api';
 
@@ -8,24 +9,59 @@ use Search::Elasticsearch::Util qw(throw);
 use namespace::clean;
 
 our %Handler = (
-    string => sub {"$_[0]"},
-    list   => sub {
-        ref $_[0] eq 'ARRAY'
-            ? join( ',', @{ shift() } )
-            : shift();
-    },
-    boolean => sub {
-        $_[0] && $_[0] ne 'false' ? 'true' : 'false';
-    },
-    enum => sub {
-        ref $_[0] eq 'ARRAY'
-            ? join( ',', @{ shift() } )
-            : shift();
-    },
-    number => sub { 0 + $_[0] },
-    time   => sub {"$_[0]"}
+    string  => \&_string,
+    time    => \&_string,
+    date    => \&_string,
+    list    => \&_list,
+    boolean => \&_bool,
+    enum    => \&_list,
+    number  => \&_num,
+    int     => \&_num,
+    float   => \&_num,
+    double  => \&_num,
 );
 
+#===================================
+sub _bool {
+#===================================
+    my $val = _detect_bool(@_);
+    return ( $val && $val ne 'false' ) ? 'true' : 'false';
+}
+
+#===================================
+sub _detect_bool {
+#===================================
+    my $val = shift;
+    return '' unless defined $val;
+    if ( ref $val eq 'SCALAR' ) {
+        return 'false' if $$val eq 0;
+        return 'true'  if $$val eq 1;
+    }
+    elsif ( UNIVERSAL::isa( $val, "JSON::PP::Boolean" ) ) {
+        return "$val" ? 'true' : 'false';
+    }
+    return "$val";
+}
+
+#===================================
+sub _list {
+#===================================
+    return join ",", map { _detect_bool($_) }    #
+        ref $_[0] eq 'ARRAY' ? @{ $_[0] } : $_[0];
+}
+
+#===================================
+sub _num {
+#===================================
+    return 0 + $_[0];
+}
+
+#===================================
+sub _string {
+#===================================
+    return "$_[0]";
+}
+
 #===================================
 sub _qs_init {
 #===================================
@@ -60,15 +96,15 @@ Search::Elasticsearch::Role::API - Provides common functionality for API impleme
 
 =head1 VERSION
 
-version 5.00
+version 6.80_01
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
