@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Role::CxnPool::Sniff;
-$Search::Elasticsearch::Role::CxnPool::Sniff::VERSION = '5.00';
-use Moo::Role;
+$Search::Elasticsearch::Role::CxnPool::Sniff::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Role::CxnPool::Sniff::VERSION = '6.8001';use Moo::Role;
 with 'Search::Elasticsearch::Role::CxnPool';
 requires 'next_cxn', 'sniff';
 use namespace::clean;
@@ -97,7 +98,7 @@ Search::Elasticsearch::Role::CxnPool::Sniff - A CxnPool role for connecting to a
 
 =head1 VERSION
 
-version 5.00
+version 6.80_01
 
 =head1 CONFIGURATION
 
@@ -161,11 +162,11 @@ accepted.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
