@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Role::CxnPool::Static::NoPing;
-$Search::Elasticsearch::Role::CxnPool::Static::NoPing::VERSION = '5.00';
-use Moo::Role;
+$Search::Elasticsearch::Role::CxnPool::Static::NoPing::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Role::CxnPool::Static::NoPing::VERSION = '6.8001';use Moo::Role;
 with 'Search::Elasticsearch::Role::CxnPool';
 
 use namespace::clean;
@@ -79,15 +80,15 @@ Search::Elasticsearch::Role::CxnPool::Static::NoPing - A CxnPool for connecting
 
 =head1 VERSION
 
-version 5.00
+version 6.80_01
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
