@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Role::Logger;
-$Search::Elasticsearch::Role::Logger::VERSION = '5.02';
-use Moo::Role;
+$Search::Elasticsearch::Role::Logger::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Role::Logger::VERSION = '6.8001';use Moo::Role;
 
 use URI();
 use Try::Tiny;
@@ -59,7 +60,7 @@ sub trace_request {
     return unless $self->is_trace;
 
     my $uri = URI->new( 'http://localhost:9200' . $params->{path} );
-    my %qs = ( %{ $params->{qs} }, pretty => 1 );
+    my %qs = ( %{ $params->{qs} }, pretty => "true" );
     $uri->query_form( [ map { $_, $qs{$_} } sort keys %qs ] );
 
     my $body
@@ -67,16 +68,19 @@ sub trace_request {
         ? $self->serializer->encode_pretty( $params->{body} )
         : $params->{data};
 
+    my $content_type = '';
     if ( defined $body ) {
         $body =~ s/'/\\u0027/g;
-        $body = " -d '\n$body'\n";
+        $body         = " -d '\n$body'\n";
+        $content_type = '-H "Content-type: ' . $params->{mime_type} . '" ';
     }
     else { $body = "\n" }
 
     my $msg = sprintf(
-        "# Request to: %s\n"         #
-            . "curl -X%s '%s'%s",    #
+        "# Request to: %s\n"           #
+            . "curl %s-X%s '%s'%s",    #
         $cxn->stringify,
+        $content_type,
         $params->{method},
         $uri,
         $body
@@ -132,7 +136,8 @@ sub trace_comment {
 sub deprecation {
 #===================================
     my $self = shift;
-    $self->deprecate_handle->warnf( "[DEPRECATION] %s. In request: %s", @_ );
+
+    $self->deprecate_handle->warnf( "[DEPRECATION] %s - In request: %s", @_ );
 }
 1;
 
@@ -150,7 +155,7 @@ Search::Elasticsearch::Role::Logger - Provides common functionality to Logger im
 
 =head1 VERSION
 
-version 5.02
+version 6.80_01
 
 =head1 DESCRIPTION
 
@@ -252,11 +257,11 @@ Issues a deprecation warning to the deprecation logger.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
