@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Role::Serializer::JSON;
-$Search::Elasticsearch::Role::Serializer::JSON::VERSION = '5.01';
-use Moo::Role;
+$Search::Elasticsearch::Role::Serializer::JSON::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Role::Serializer::JSON::VERSION = '6.8001';use Moo::Role;
 requires 'JSON';
 
 use Search::Elasticsearch::Util qw(throw);
@@ -103,7 +104,7 @@ Search::Elasticsearch::Role::Serializer::JSON - A Serializer role for JSON modul
 
 =head1 VERSION
 
-version 5.01
+version 6.80_01
 
 =head1 DESCRIPTION
 
@@ -150,11 +151,11 @@ returned as is.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
