@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Serializer::JSON;
-$Search::Elasticsearch::Serializer::JSON::VERSION = '5.02';
-use Moo;
+$Search::Elasticsearch::Serializer::JSON::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Serializer::JSON::VERSION = '6.8001';use Moo;
 use JSON::MaybeXS 1.002002 ();
 
 has 'JSON' => ( is => 'ro', default => sub { JSON::MaybeXS->new->utf8(1) } );
@@ -24,7 +25,7 @@ Search::Elasticsearch::Serializer::JSON - The default JSON Serializer, using JSO
 
 =head1 VERSION
 
-version 5.02
+version 6.80_01
 
 =head1 SYNOPSIS
 
@@ -67,11 +68,11 @@ See their documentation for details.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
