@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Serializer::JSON::PP;
-$Search::Elasticsearch::Serializer::JSON::PP::VERSION = '5.00';
-use Moo;
+$Search::Elasticsearch::Serializer::JSON::PP::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Serializer::JSON::PP::VERSION = '6.8001';use Moo;
 use JSON::PP;
 
 has 'JSON' => ( is => 'ro', default => sub { JSON::PP->new->utf8(1) } );
@@ -23,7 +24,7 @@ Search::Elasticsearch::Serializer::JSON::PP - A JSON Serializer using JSON::PP
 
 =head1 VERSION
 
-version 5.00
+version 6.80_01
 
 =head1 SYNOPSIS
 
@@ -56,11 +57,11 @@ This class does L<Search::Elasticsearch::Role::Serializer::JSON>.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
