@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Transport;
-$Search::Elasticsearch::Transport::VERSION = '5.00';
-use Moo;
+$Search::Elasticsearch::Transport::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Transport::VERSION = '6.8001';use Moo;
 
 use URI();
 use Time::HiRes qw(time);
@@ -72,7 +73,7 @@ Search::Elasticsearch::Transport - Provides interface between the client class a
 
 =head1 VERSION
 
-version 5.00
+version 6.80_01
 
 =head1 DESCRIPTION
 
@@ -91,7 +92,7 @@ L<Search::Elasticsearch::Role::Is_Sync>.
         send_get_body_as => 'POST'
     );
 
-Certain endpoints like L<Search::Elasticsearch::Client::5_0::Direct/search()>
+Certain endpoints like L<Search::Elasticsearch::Client::6_0::Direct/search()>
 default to using a C<GET> method, even when they include a request body.
 Some proxy servers do not support C<GET> requests with a body.  To work
 around this, the C<send_get_body_as>  parameter accepts the following:
@@ -160,11 +161,11 @@ JSON) or using the special I<bulk> format:  C<"std"> or C<"bulk">.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
